<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns:svrl="http://purl.oclc.org/dsdl/svrl" xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:qdt="urn:un:unece:uncefact:data:standard:QualifiedDataType:100"
                xmlns:ram="urn:un:unece:uncefact:data:standard:ReusableAggregateBusinessInformationEntity:100"
                xmlns:rsm="urn:un:unece:uncefact:data:standard:CrossIndustryInvoice:100"
                xmlns:saxon="http://saxon.sf.net/" xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:udt="urn:un:unece:uncefact:data:standard:UnqualifiedDataType:100"
                xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="2.0">
    <!--Implementers: please note that overriding process-prolog or process-root is
        the preferred method for meta-stylesheets to use where possible. -->

    <xsl:param name="archiveDirParameter"/>
    <xsl:param name="archiveNameParameter"/>
    <xsl:param name="fileNameParameter"/>
    <xsl:param name="fileDirParameter"/>
    <xsl:variable name="document-uri">
        <xsl:value-of select="document-uri(/)"/>
    </xsl:variable>

    <!--PHASES-->


    <!--PROLOG-->
    <xsl:output indent="yes" method="xml" omit-xml-declaration="no" standalone="yes"/>

    <!--XSD TYPES FOR XSLT2-->


    <!--KEYS AND FUNCTIONS-->


    <!--DEFAULT RULES-->


    <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
    <!--This mode can be used to generate an ugly though full XPath for locators-->
    <xsl:template match="*" mode="schematron-select-full-path">
        <xsl:apply-templates mode="schematron-get-full-path" select="."/>
    </xsl:template>

    <!--MODE: SCHEMATRON-FULL-PATH-->
    <!--This mode can be used to generate an ugly though full XPath for locators-->
    <xsl:template match="*" mode="schematron-get-full-path">
        <xsl:apply-templates mode="schematron-get-full-path" select="parent::*"/>
        <xsl:text>/</xsl:text>
        <xsl:choose>
            <xsl:when test="namespace-uri()=''">
                <xsl:value-of select="name()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>*:</xsl:text>
                <xsl:value-of select="local-name()"/>
                <xsl:text>[namespace-uri()='</xsl:text>
                <xsl:value-of select="namespace-uri()"/>
                <xsl:text>']</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:variable name="preceding"
                      select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
        <xsl:text>[</xsl:text>
        <xsl:value-of select="1+ $preceding"/>
        <xsl:text>]</xsl:text>
    </xsl:template>
    <xsl:template match="@*" mode="schematron-get-full-path">
        <xsl:apply-templates mode="schematron-get-full-path" select="parent::*"/>
        <xsl:text>/</xsl:text>
        <xsl:choose>
            <xsl:when test="namespace-uri()=''">@
                <xsl:value-of select="name()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>@*[local-name()='</xsl:text>
                <xsl:value-of select="local-name()"/>
                <xsl:text>' and namespace-uri()='</xsl:text>
                <xsl:value-of select="namespace-uri()"/>
                <xsl:text>']</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!--MODE: SCHEMATRON-FULL-PATH-2-->
    <!--This mode can be used to generate prefixed XPath for humans-->
    <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
        <xsl:for-each select="ancestor-or-self::*">
            <xsl:text>/</xsl:text>
            <xsl:value-of select="name(.)"/>
            <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
                <xsl:text>[</xsl:text>
                <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
                <xsl:text>]</xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:if test="not(self::*)">
            <xsl:text/>/@
            <xsl:value-of select="name(.)"/>
        </xsl:if>
    </xsl:template>
    <!--MODE: SCHEMATRON-FULL-PATH-3-->
    <!--This mode can be used to generate prefixed XPath for humans
        (Top-level element has index)-->

    <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
        <xsl:for-each select="ancestor-or-self::*">
            <xsl:text>/</xsl:text>
            <xsl:value-of select="name(.)"/>
            <xsl:if test="parent::*">
                <xsl:text>[</xsl:text>
                <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
                <xsl:text>]</xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:if test="not(self::*)">
            <xsl:text/>/@
            <xsl:value-of select="name(.)"/>
        </xsl:if>
    </xsl:template>

    <!--MODE: GENERATE-ID-FROM-PATH -->
    <xsl:template match="/" mode="generate-id-from-path"/>
    <xsl:template match="text()" mode="generate-id-from-path">
        <xsl:apply-templates mode="generate-id-from-path" select="parent::*"/>
        <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
    </xsl:template>
    <xsl:template match="comment()" mode="generate-id-from-path">
        <xsl:apply-templates mode="generate-id-from-path" select="parent::*"/>
        <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
    </xsl:template>
    <xsl:template match="processing-instruction()" mode="generate-id-from-path">
        <xsl:apply-templates mode="generate-id-from-path" select="parent::*"/>
        <xsl:value-of
                select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
    </xsl:template>
    <xsl:template match="@*" mode="generate-id-from-path">
        <xsl:apply-templates mode="generate-id-from-path" select="parent::*"/>
        <xsl:value-of select="concat('.@', name())"/>
    </xsl:template>
    <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
        <xsl:apply-templates mode="generate-id-from-path" select="parent::*"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
    </xsl:template>

    <!--MODE: GENERATE-ID-2 -->
    <xsl:template match="/" mode="generate-id-2">U</xsl:template>
    <xsl:template match="*" mode="generate-id-2" priority="2">
        <xsl:text>U</xsl:text>
        <xsl:number count="*" level="multiple"/>
    </xsl:template>
    <xsl:template match="node()" mode="generate-id-2">
        <xsl:text>U.</xsl:text>
        <xsl:number count="*" level="multiple"/>
        <xsl:text>n</xsl:text>
        <xsl:number count="node()"/>
    </xsl:template>
    <xsl:template match="@*" mode="generate-id-2">
        <xsl:text>U.</xsl:text>
        <xsl:number count="*" level="multiple"/>
        <xsl:text>_</xsl:text>
        <xsl:value-of select="string-length(local-name(.))"/>
        <xsl:text>_</xsl:text>
        <xsl:value-of select="translate(name(),':','.')"/>
    </xsl:template>
    <!--Strip characters-->
    <xsl:template match="text()" priority="-1"/>

    <!--SCHEMA SETUP-->
    <xsl:template match="/">
        <svrl:schematron-output schemaVersion="iso" title="Schema for Factur-X; 1.07.2; Accounting, MINIMUM">
            <xsl:comment>
                <xsl:value-of select="$archiveDirParameter"/>
                 
                <xsl:value-of select="$archiveNameParameter"/>
                 
                <xsl:value-of select="$fileNameParameter"/>
                 
                <xsl:value-of select="$fileDirParameter"/>
            </xsl:comment>
            <svrl:ns-prefix-in-attribute-values prefix="rsm"
                                                uri="urn:un:unece:uncefact:data:standard:CrossIndustryInvoice:100"/>
            <svrl:ns-prefix-in-attribute-values prefix="qdt"
                                                uri="urn:un:unece:uncefact:data:standard:QualifiedDataType:100"/>
            <svrl:ns-prefix-in-attribute-values prefix="ram"
                                                uri="urn:un:unece:uncefact:data:standard:ReusableAggregateBusinessInformationEntity:100"/>
            <svrl:ns-prefix-in-attribute-values prefix="udt"
                                                uri="urn:un:unece:uncefact:data:standard:UnqualifiedDataType:100"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M5" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M6" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M7" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M8" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M9" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M10" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M11" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M12" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M13" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M14" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M15" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M16" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M17" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M18" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M19" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M20" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M21" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M22" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M23" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M24" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M25" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M26" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M27" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M28" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M29" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M30" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M31" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M32" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M33" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M34" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M35" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M36" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M37" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M38" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M39" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M40" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M41" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M42" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M43" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M44" select="/"/>
            <svrl:active-pattern>
                <xsl:attribute name="document">
                    <xsl:value-of select="document-uri(/)"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M45" select="/"/>
        </svrl:schematron-output>
    </xsl:template>

    <!--SCHEMATRON PATTERNS-->
    <svrl:text>Schema for Factur-X; 1.07.2; Accounting, MINIMUM</svrl:text>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="//ram:SellerTradeParty" mode="M5" priority="1000">
        <svrl:fired-rule context="//ram:SellerTradeParty"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="(ram:ID) or (ram:GlobalID) or (ram:SpecifiedLegalOrganization/ram:ID) or (ram:SpecifiedTaxRegistration/ram:ID[@schemeID='VA'])"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(ram:ID) or (ram:GlobalID) or (ram:SpecifiedLegalOrganization/ram:ID) or (ram:SpecifiedTaxRegistration/ram:ID[@schemeID='VA'])">
                    <xsl:attribute name="id">FX-SCH-A-000001</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-CO-26]-In order for the buyer to automatically identify a supplier, the Seller identifier
                        (BT-29), the Seller legal registration identifier (BT-30) and/or the Seller VAT identifier
                        (BT-31) shall be present.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M5" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M5" priority="-1"/>
    <xsl:template match="@*|node()" mode="M5" priority="-2">
        <xsl:apply-templates mode="M5" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="//ram:SpecifiedTaxRegistration/ram:ID[@schemeID='VA']" mode="M6" priority="1000">
        <svrl:fired-rule context="//ram:SpecifiedTaxRegistration/ram:ID[@schemeID='VA']"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="contains(' 1A AD AE AF AG AI AL AM AN AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BL BJ BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH EL ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS XI YE YT ZA ZM ZW ', concat(' ', substring(.,1,2), ' '))"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="contains(' 1A AD AE AF AG AI AL AM AN AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BL BJ BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH EL ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS XI YE YT ZA ZM ZW ', concat(' ', substring(.,1,2), ' '))">
                    <xsl:attribute name="id">FX-SCH-A-000002</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-CO-09]-The Seller VAT identifier (BT-31), the Seller tax representative VAT identifier
                        (BT-63) and the Buyer VAT identifier (BT-48) shall have a prefix in accordance with ISO code ISO
                        3166-1 alpha-2 by which the country of issue may be identified. Nevertheless, Greece may use the
                        prefix ‘EL’.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M6" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M6" priority="-1"/>
    <xsl:template match="@*|node()" mode="M6" priority="-2">
        <xsl:apply-templates mode="M6" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="//ram:SpecifiedTradeSettlementHeaderMonetarySummation" mode="M7" priority="1000">
        <svrl:fired-rule context="//ram:SpecifiedTradeSettlementHeaderMonetarySummation"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(ram:TaxBasisTotalAmount)"/>
            <xsl:otherwise>
                <svrl:failed-assert test="(ram:TaxBasisTotalAmount)">
                    <xsl:attribute name="id">FX-SCH-A-000003</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-13]-An Invoice shall have the Invoice total amount without VAT (BT-109).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(ram:GrandTotalAmount)"/>
            <xsl:otherwise>
                <svrl:failed-assert test="(ram:GrandTotalAmount)">
                    <xsl:attribute name="id">FX-SCH-A-000004</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-14]-An Invoice shall have the Invoice total amount with VAT (BT-112).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(ram:DuePayableAmount)"/>
            <xsl:otherwise>
                <svrl:failed-assert test="(ram:DuePayableAmount)">
                    <xsl:attribute name="id">FX-SCH-A-000005</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-15]-An Invoice shall have the Amount due for payment (BT-115).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="string-length(substring-after(ram:TaxBasisTotalAmount,'.'))&lt;=2"/>
            <xsl:otherwise>
                <svrl:failed-assert test="string-length(substring-after(ram:TaxBasisTotalAmount,'.'))&lt;=2">
                    <xsl:attribute name="id">FX-SCH-A-000006</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-DEC-12]-The allowed maximum number of decimals for the Invoice total amount without VAT
                        (BT-109) is 2.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="not(ram:TaxTotalAmount) or ram:TaxTotalAmount[(@currencyID =/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode and . = round(. * 100) div 100) or not (@currencyID =/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode)]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="not(ram:TaxTotalAmount) or ram:TaxTotalAmount[(@currencyID =/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode and . = round(. * 100) div 100) or not (@currencyID =/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode)]">
                    <xsl:attribute name="id">FX-SCH-A-000007</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-DEC-13]-The allowed maximum number of decimals for the Invoice total VAT amount (BT-110) is
                        2.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="string-length(substring-after(ram:GrandTotalAmount,'.'))&lt;=2"/>
            <xsl:otherwise>
                <svrl:failed-assert test="string-length(substring-after(ram:GrandTotalAmount,'.'))&lt;=2">
                    <xsl:attribute name="id">FX-SCH-A-000008</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-DEC-14]-The allowed maximum number of decimals for the Invoice total amount with VAT
                        (BT-112) is 2.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="string-length(substring-after(ram:DuePayableAmount,'.'))&lt;=2"/>
            <xsl:otherwise>
                <svrl:failed-assert test="string-length(substring-after(ram:DuePayableAmount,'.'))&lt;=2">
                    <xsl:attribute name="id">FX-SCH-A-000009</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-DEC-18]-The allowed maximum number of decimals for the Amount due for payment (BT-115) is 2.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M7" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M7" priority="-1"/>
    <xsl:template match="@*|node()" mode="M7" priority="-2">
        <xsl:apply-templates mode="M7" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice" mode="M8" priority="1000">
        <svrl:fired-rule context="/rsm:CrossIndustryInvoice"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="(rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID != '')"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID != '')">
                    <xsl:attribute name="id">FX-SCH-A-000010</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-01]-An Invoice shall have a Specification identifier (BT-24).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(rsm:ExchangedDocument/ram:ID !='')"/>
            <xsl:otherwise>
                <svrl:failed-assert test="(rsm:ExchangedDocument/ram:ID !='')">
                    <xsl:attribute name="id">FX-SCH-A-000011</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-02]-An Invoice shall have an Invoice number (BT-1).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString[@format='102']!='')"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString[@format='102']!='')">
                    <xsl:attribute name="id">FX-SCH-A-000012</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-03]-An Invoice shall have an Invoice issue date (BT-2).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="(rsm:ExchangedDocument/ram:TypeCode!='')"/>
            <xsl:otherwise>
                <svrl:failed-assert test="(rsm:ExchangedDocument/ram:TypeCode!='')">
                    <xsl:attribute name="id">FX-SCH-A-000013</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-04]-An Invoice shall have an Invoice type code (BT-3).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode!='')"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode!='')">
                    <xsl:attribute name="id">FX-SCH-A-000014</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-05]-An Invoice shall have an Invoice currency code (BT-5).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:Name!='')"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:Name!='')">
                    <xsl:attribute name="id">FX-SCH-A-000015</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-06]-An Invoice shall contain the Seller name (BT-27).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when
                    test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:Name!='')"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="(rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:Name!='')">
                    <xsl:attribute name="id">FX-SCH-A-000016</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-07]-An Invoice shall contain the Buyer name (BT-44).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="//ram:SellerTradeParty/ram:PostalTradeAddress"/>
            <xsl:otherwise>
                <svrl:failed-assert test="//ram:SellerTradeParty/ram:PostalTradeAddress">
                    <xsl:attribute name="id">FX-SCH-A-000017</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-08]-An Invoice shall contain the Seller postal address (BG-5).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="//ram:SellerTradeParty/ram:PostalTradeAddress/ram:CountryID!=''"/>
            <xsl:otherwise>
                <svrl:failed-assert test="//ram:SellerTradeParty/ram:PostalTradeAddress/ram:CountryID!=''">
                    <xsl:attribute name="id">FX-SCH-A-000018</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        [BR-09]-The Seller postal address (BG-5) shall contain a Seller country code (BT-40).
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M8" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M8" priority="-1"/>
    <xsl:template match="@*|node()" mode="M8" priority="-2">
        <xsl:apply-templates mode="M8" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument" mode="M9" priority="1000">
        <svrl:fired-rule context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:TypeCode)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:TypeCode)=1">
                    <xsl:attribute name="id">FX-SCH-A-000020</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:TypeCode' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M9" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M9" priority="-1"/>
    <xsl:template match="@*|node()" mode="M9" priority="-2">
        <xsl:apply-templates mode="M9" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:ID[@schemeID]" mode="M10" priority="1000">
        <svrl:fired-rule context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:ID[@schemeID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @schemeID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M10" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M10" priority="-1"/>
    <xsl:template match="@*|node()" mode="M10" priority="-2">
        <xsl:apply-templates mode="M10" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString"
                  mode="M11" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="@format"/>
            <xsl:otherwise>
                <svrl:failed-assert test="@format">
                    <xsl:attribute name="id">FX-SCH-A-000021</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Attribute '@format' is required in this context.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M11" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M11" priority="-1"/>
    <xsl:template match="@*|node()" mode="M11" priority="-2">
        <xsl:apply-templates mode="M11" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString[@format]"
                  mode="M12" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:IssueDateTime/udt:DateTimeString[@format]"/>
        <xsl:variable name="codeValue3" select="@format"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=3]/enumeration[@value=$codeValue3]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=3]/enumeration[@value=$codeValue3]">
                    <xsl:attribute name="id">FX-SCH-A-000022</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of '@format' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M12" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M12" priority="-1"/>
    <xsl:template match="@*|node()" mode="M12" priority="-2">
        <xsl:apply-templates mode="M12" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:TypeCode" mode="M13" priority="1000">
        <svrl:fired-rule context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocument/ram:TypeCode"/>
        <xsl:variable name="codeValue2" select="."/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=2]/enumeration[@value=$codeValue2]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=2]/enumeration[@value=$codeValue2]">
                    <xsl:attribute name="id">FX-SCH-A-000023</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of 'ram:TypeCode' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M13" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M13" priority="-1"/>
    <xsl:template match="@*|node()" mode="M13" priority="-2">
        <xsl:apply-templates mode="M13" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext" mode="M14" priority="1000">
        <svrl:fired-rule context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:BusinessProcessSpecifiedDocumentContextParameter)&lt;=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:BusinessProcessSpecifiedDocumentContextParameter)&lt;=1">
                    <xsl:attribute name="id">FX-SCH-A-000024</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:BusinessProcessSpecifiedDocumentContextParameter' may occur at maximum 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:GuidelineSpecifiedDocumentContextParameter)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:GuidelineSpecifiedDocumentContextParameter)=1">
                    <xsl:attribute name="id">FX-SCH-A-000025</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:GuidelineSpecifiedDocumentContextParameter' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M14" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M14" priority="-1"/>
    <xsl:template match="@*|node()" mode="M14" priority="-2">
        <xsl:apply-templates mode="M14" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:BusinessProcessSpecifiedDocumentContextParameter"
            mode="M15" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:BusinessProcessSpecifiedDocumentContextParameter"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M15" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M15" priority="-1"/>
    <xsl:template match="@*|node()" mode="M15" priority="-2">
        <xsl:apply-templates mode="M15" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:BusinessProcessSpecifiedDocumentContextParameter/ram:ID[@schemeID]"
            mode="M16" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:BusinessProcessSpecifiedDocumentContextParameter/ram:ID[@schemeID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @schemeID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M16" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M16" priority="-1"/>
    <xsl:template match="@*|node()" mode="M16" priority="-2">
        <xsl:apply-templates mode="M16" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter"
            mode="M17" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M17" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M17" priority="-1"/>
    <xsl:template match="@*|node()" mode="M17" priority="-2">
        <xsl:apply-templates mode="M17" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID"
            mode="M18" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID"/>
        <xsl:variable name="codeValue1" select="."/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=1]/enumeration[@value=$codeValue1]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=1]/enumeration[@value=$codeValue1]">
                    <xsl:attribute name="id">FX-SCH-A-000026</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of 'ram:ID' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M18" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M18" priority="-1"/>
    <xsl:template match="@*|node()" mode="M18" priority="-2">
        <xsl:apply-templates mode="M18" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID[@schemeID]"
            mode="M19" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:ExchangedDocumentContext/ram:GuidelineSpecifiedDocumentContextParameter/ram:ID[@schemeID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @schemeID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M19" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M19" priority="-1"/>
    <xsl:template match="@*|node()" mode="M19" priority="-2">
        <xsl:apply-templates mode="M19" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement"
                  mode="M20" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:SellerTradeParty)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:SellerTradeParty)=1">
                    <xsl:attribute name="id">FX-SCH-A-000027</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:SellerTradeParty' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:BuyerTradeParty)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:BuyerTradeParty)=1">
                    <xsl:attribute name="id">FX-SCH-A-000028</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:BuyerTradeParty' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M20" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M20" priority="-1"/>
    <xsl:template match="@*|node()" mode="M20" priority="-2">
        <xsl:apply-templates mode="M20" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerOrderReferencedDocument"
            mode="M21" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerOrderReferencedDocument"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:IssuerAssignedID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:IssuerAssignedID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000029</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:IssuerAssignedID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M21" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M21" priority="-1"/>
    <xsl:template match="@*|node()" mode="M21" priority="-2">
        <xsl:apply-templates mode="M21" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerOrderReferencedDocument/ram:IssuerAssignedID[@schemeID]"
            mode="M22" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerOrderReferencedDocument/ram:IssuerAssignedID[@schemeID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @schemeID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M22" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M22" priority="-1"/>
    <xsl:template match="@*|node()" mode="M22" priority="-2">
        <xsl:apply-templates mode="M22" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty"
            mode="M23" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:Name)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:Name)=1">
                    <xsl:attribute name="id">FX-SCH-A-000030</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:Name' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M23" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M23" priority="-1"/>
    <xsl:template match="@*|node()" mode="M23" priority="-2">
        <xsl:apply-templates mode="M23" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:PostalTradeAddress"
            mode="M24" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:PostalTradeAddress"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Element 'ram:PostalTradeAddress' is marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M24" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M24" priority="-1"/>
    <xsl:template match="@*|node()" mode="M24" priority="-2">
        <xsl:apply-templates mode="M24" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedLegalOrganization"
            mode="M25" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedLegalOrganization"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M25" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M25" priority="-1"/>
    <xsl:template match="@*|node()" mode="M25" priority="-2">
        <xsl:apply-templates mode="M25" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedLegalOrganization/ram:ID[@schemeID]"
            mode="M26" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedLegalOrganization/ram:ID[@schemeID]"/>
        <xsl:variable name="codeValue4" select="@schemeID"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=4]/enumeration[@value=$codeValue4]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=4]/enumeration[@value=$codeValue4]">
                    <xsl:attribute name="id">FX-SCH-A-000031</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of '@schemeID' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M26" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M26" priority="-1"/>
    <xsl:template match="@*|node()" mode="M26" priority="-2">
        <xsl:apply-templates mode="M26" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedTaxRegistration"
            mode="M27" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:BuyerTradeParty/ram:SpecifiedTaxRegistration"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Element 'ram:SpecifiedTaxRegistration' is marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M27" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M27" priority="-1"/>
    <xsl:template match="@*|node()" mode="M27" priority="-2">
        <xsl:apply-templates mode="M27" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty"
            mode="M28" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:Name)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:Name)=1">
                    <xsl:attribute name="id">FX-SCH-A-000030</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:Name' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:PostalTradeAddress)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:PostalTradeAddress)=1">
                    <xsl:attribute name="id">FX-SCH-A-000032</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:PostalTradeAddress' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;])&lt;=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;])&lt;=1">
                    <xsl:attribute name="id">FX-SCH-A-000033</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element variant 'ram:SpecifiedTaxRegistration[ram:ID/@schemeID="VA"]' may occur at maximum 1
                        times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;])&lt;=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;])&lt;=1">
                    <xsl:attribute name="id">FX-SCH-A-000034</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element variant 'ram:SpecifiedTaxRegistration[ram:ID/@schemeID="FC"]' may occur at maximum 1
                        times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M28" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M28" priority="-1"/>
    <xsl:template match="@*|node()" mode="M28" priority="-2">
        <xsl:apply-templates mode="M28" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:PostalTradeAddress"
            mode="M29" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:PostalTradeAddress"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:CountryID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:CountryID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000035</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:CountryID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M29" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M29" priority="-1"/>
    <xsl:template match="@*|node()" mode="M29" priority="-2">
        <xsl:apply-templates mode="M29" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:PostalTradeAddress/ram:CountryID"
            mode="M30" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:PostalTradeAddress/ram:CountryID"/>
        <xsl:variable name="codeValue5" select="."/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=5]/enumeration[@value=$codeValue5]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=5]/enumeration[@value=$codeValue5]">
                    <xsl:attribute name="id">FX-SCH-A-000036</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of 'ram:CountryID' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M30" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M30" priority="-1"/>
    <xsl:template match="@*|node()" mode="M30" priority="-2">
        <xsl:apply-templates mode="M30" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedLegalOrganization/ram:ID[@schemeID]"
            mode="M31" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedLegalOrganization/ram:ID[@schemeID]"/>
        <xsl:variable name="codeValue4" select="@schemeID"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=4]/enumeration[@value=$codeValue4]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=4]/enumeration[@value=$codeValue4]">
                    <xsl:attribute name="id">FX-SCH-A-000031</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of '@schemeID' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M31" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M31" priority="-1"/>
    <xsl:template match="@*|node()" mode="M31" priority="-2">
        <xsl:apply-templates mode="M31" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ not(ram:ID/@schemeID=&quot;VA&quot;) and  not(ram:ID/@schemeID=&quot;FC&quot;)]"
            mode="M32" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ not(ram:ID/@schemeID=&quot;VA&quot;) and  not(ram:ID/@schemeID=&quot;FC&quot;)]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Element variant 'ram:SpecifiedTaxRegistration[ not(ram:ID/@schemeID="VA") and
                    not(ram:ID/@schemeID="FC")]' is marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M32" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M32" priority="-1"/>
    <xsl:template match="@*|node()" mode="M32" priority="-2">
        <xsl:apply-templates mode="M32" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;]"
            mode="M33" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;]"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M33" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M33" priority="-1"/>
    <xsl:template match="@*|node()" mode="M33" priority="-2">
        <xsl:apply-templates mode="M33" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;]/ram:ID"
            mode="M34" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;FC&quot;]/ram:ID"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="@schemeID"/>
            <xsl:otherwise>
                <svrl:failed-assert test="@schemeID">
                    <xsl:attribute name="id">FX-SCH-A-000037</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Attribute '@schemeID' is required in this context.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M34" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M34" priority="-1"/>
    <xsl:template match="@*|node()" mode="M34" priority="-2">
        <xsl:apply-templates mode="M34" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;]"
            mode="M35" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;]"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:ID)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:ID)=1">
                    <xsl:attribute name="id">FX-SCH-A-000019</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:ID' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M35" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M35" priority="-1"/>
    <xsl:template match="@*|node()" mode="M35" priority="-2">
        <xsl:apply-templates mode="M35" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;]/ram:ID"
            mode="M36" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeAgreement/ram:SellerTradeParty/ram:SpecifiedTaxRegistration[ram:ID/@schemeID=&quot;VA&quot;]/ram:ID"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="@schemeID"/>
            <xsl:otherwise>
                <svrl:failed-assert test="@schemeID">
                    <xsl:attribute name="id">FX-SCH-A-000037</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Attribute '@schemeID' is required in this context.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M36" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M36" priority="-1"/>
    <xsl:template match="@*|node()" mode="M36" priority="-2">
        <xsl:apply-templates mode="M36" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement"
                  mode="M37" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:InvoiceCurrencyCode)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:InvoiceCurrencyCode)=1">
                    <xsl:attribute name="id">FX-SCH-A-000038</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:InvoiceCurrencyCode' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:SpecifiedTradeSettlementHeaderMonetarySummation)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:SpecifiedTradeSettlementHeaderMonetarySummation)=1">
                    <xsl:attribute name="id">FX-SCH-A-000039</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:SpecifiedTradeSettlementHeaderMonetarySummation' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M37" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M37" priority="-1"/>
    <xsl:template match="@*|node()" mode="M37" priority="-2">
        <xsl:apply-templates mode="M37" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode"
            mode="M38" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:InvoiceCurrencyCode"/>
        <xsl:variable name="codeValue6" select="."/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=6]/enumeration[@value=$codeValue6]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=6]/enumeration[@value=$codeValue6]">
                    <xsl:attribute name="id">FX-SCH-A-000040</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of 'ram:InvoiceCurrencyCode' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M38" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M38" priority="-1"/>
    <xsl:template match="@*|node()" mode="M38" priority="-2">
        <xsl:apply-templates mode="M38" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation"
            mode="M39" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:TaxBasisTotalAmount)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:TaxBasisTotalAmount)=1">
                    <xsl:attribute name="id">FX-SCH-A-000041</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:TaxBasisTotalAmount' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode])&lt;=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode])&lt;=1">
                    <xsl:attribute name="id">FX-SCH-A-000042</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element variant 'ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode]' may occur at
                        maximum 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:GrandTotalAmount)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:GrandTotalAmount)=1">
                    <xsl:attribute name="id">FX-SCH-A-000043</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:GrandTotalAmount' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="count(ram:DuePayableAmount)=1"/>
            <xsl:otherwise>
                <svrl:failed-assert test="count(ram:DuePayableAmount)=1">
                    <xsl:attribute name="id">FX-SCH-A-000044</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Element 'ram:DuePayableAmount' must occur exactly 1 times.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M39" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M39" priority="-1"/>
    <xsl:template match="@*|node()" mode="M39" priority="-2">
        <xsl:apply-templates mode="M39" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:DuePayableAmount[@currencyID]"
            mode="M40" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:DuePayableAmount[@currencyID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @currencyID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M40" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M40" priority="-1"/>
    <xsl:template match="@*|node()" mode="M40" priority="-2">
        <xsl:apply-templates mode="M40" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:GrandTotalAmount[@currencyID]"
            mode="M41" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:GrandTotalAmount[@currencyID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @currencyID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M41" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M41" priority="-1"/>
    <xsl:template match="@*|node()" mode="M41" priority="-2">
        <xsl:apply-templates mode="M41" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxBasisTotalAmount[@currencyID]"
            mode="M42" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxBasisTotalAmount[@currencyID]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Attribute @currencyID' marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M42" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M42" priority="-1"/>
    <xsl:template match="@*|node()" mode="M42" priority="-2">
        <xsl:apply-templates mode="M42" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[ not(@currencyID=../../ram:InvoiceCurrencyCode) and  not(@currencyID=../../ram:TaxCurrencyCode)]"
            mode="M43" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[ not(@currencyID=../../ram:InvoiceCurrencyCode) and  not(@currencyID=../../ram:TaxCurrencyCode)]"/>

        <!--REPORT -->
        <xsl:if test="true()">
            <svrl:successful-report test="true()">
                <xsl:attribute name="location">
                    <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                </xsl:attribute>
                <svrl:text>
                    Element variant 'ram:TaxTotalAmount[ not(@currencyID=../../ram:InvoiceCurrencyCode) and
                    not(@currencyID=../../ram:TaxCurrencyCode)]' is marked as not used in the given context.
                </svrl:text>
            </svrl:successful-report>
        </xsl:if>
        <xsl:apply-templates mode="M43" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M43" priority="-1"/>
    <xsl:template match="@*|node()" mode="M43" priority="-2">
        <xsl:apply-templates mode="M43" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode and @currencyID]"
            mode="M44" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode and @currencyID]"/>
        <xsl:variable name="codeValue7" select="@currencyID"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=7]/enumeration[@value=$codeValue7]"/>
            <xsl:otherwise>
                <svrl:failed-assert
                        test="document('Factur-X_1.07.2_MINIMUM_codedb.xml')//cl[@id=7]/enumeration[@value=$codeValue7]">
                    <xsl:attribute name="id">FX-SCH-A-000045</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Value of '@currencyID' is not allowed.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M44" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M44" priority="-1"/>
    <xsl:template match="@*|node()" mode="M44" priority="-2">
        <xsl:apply-templates mode="M44" select="@*|*"/>
    </xsl:template>

    <!--PATTERN -->


    <!--RULE -->
    <xsl:template
            match="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode]"
            mode="M45" priority="1000">
        <svrl:fired-rule
                context="/rsm:CrossIndustryInvoice/rsm:SupplyChainTradeTransaction/ram:ApplicableHeaderTradeSettlement/ram:SpecifiedTradeSettlementHeaderMonetarySummation/ram:TaxTotalAmount[@currencyID=../../ram:InvoiceCurrencyCode]"/>

        <!--ASSERT -->
        <xsl:choose>
            <xsl:when test="@currencyID"/>
            <xsl:otherwise>
                <svrl:failed-assert test="@currencyID">
                    <xsl:attribute name="id">FX-SCH-A-000046</xsl:attribute>
                    <xsl:attribute name="location">
                        <xsl:apply-templates mode="schematron-select-full-path" select="."/>
                    </xsl:attribute>
                    <svrl:text>
                        Attribute '@currencyID' is required in this context.
                    </svrl:text>
                </svrl:failed-assert>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates mode="M45" select="@*|*"/>
    </xsl:template>
    <xsl:template match="text()" mode="M45" priority="-1"/>
    <xsl:template match="@*|node()" mode="M45" priority="-2">
        <xsl:apply-templates mode="M45" select="@*|*"/>
    </xsl:template>
</xsl:stylesheet>
